#include <stdio.h>

#include <kernel/image.h>
#include <Directory.h>
#include <Entry.h>
#include <File.h>
#include <Path.h>
#include <TypeConstants.h>

int
main() 
{
	image_info imageInfo;
	int32 cookie = 0;
	if (get_next_image_info(0, &cookie, &imageInfo) != B_OK) {
		fprintf(stderr, "unable to get next image\n");
		exit(5);
	}

	entry_ref normalizedRef;
	get_ref_for_path(imageInfo.name, &normalizedRef);

	entry_ref eref;
	eref.device = imageInfo.device;
	eref.directory = imageInfo.node;
	eref.set_name(imageInfo.name);
	
	BPath path(imageInfo.name);
	path.GetParent(&path);
	BDirectory dir(path.Path());

	BEntry entry;
	entry.SetTo(&normalizedRef);
	printf("accessing entry via entry-ref with relative path %s\n",
		entry.Exists() ? "works" : "doesn't work");

	entry.SetTo(&eref);
	printf("accessing entry via entry-ref with absolute path %s\n",
		entry.Exists() ? "works" : "doesn't work");

	entry.SetTo(&dir, normalizedRef.name);
	printf("accessing entry via directory with relative path %s\n",
		entry.Exists() ? "works" : "doesn't work");
	
	entry.SetTo(&dir, imageInfo.name);
	printf("accessing entry via directory with absolute path %s\n",
		entry.Exists() ? "works" : "doesn't work");

	BFile file;
	file.SetTo(&normalizedRef, B_READ_ONLY);
	printf("accessing file via entry-ref with relative path %s\n",
		file.InitCheck() == B_OK ? "works" : "doesn't work");
	
	file.SetTo(&eref, B_READ_ONLY);
	printf("accessing file via entry-ref with absolute path %s\n",
		file.InitCheck() == B_OK ? "works" : "doesn't work");

	file.SetTo(&dir, normalizedRef.name, B_READ_ONLY);
	printf("accessing file via directory with relative path %s\n",
		file.InitCheck() == B_OK ? "works" : "doesn't work");
	
	file.SetTo(&dir, imageInfo.name, B_READ_ONLY);
	printf("accessing file via directory with absolute path %s\n",
		file.InitCheck() == B_OK ? "works" : "doesn't work");

	return 0;
}

